@@ -3,7 +3,7 @@ BEGIN {
   $Escape::Houdini::AUTHORITY = 'cpan:YANICK';
 }
 {
-  $Escape::Houdini::VERSION = '0.1.4';
+  $Escape::Houdini::VERSION = '0.2.0';
 }
 # ABSTRACT: Perl API to Houdini, a zero-dependency C web escaping library
 
@@ -35,13 +35,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Escape::Houdini - Perl API to Houdini, a zero-dependency C web escaping library
 
 =head1 VERSION
 
-version 0.1.4
+version 0.2.0
 
 =head1 SYNOPSIS
 
@@ -56,11 +58,9 @@ I<Escape::Houdini> is a wrapper around the zero-depedency, minimalistic
 web escaping C library Houdini.
 
 This version of I<Escape::Houdini> has been built against 
-commit 
-I<e6f0ec96b85578a2fd8ab79af84493cad3a84cfb>
-(Wed Apr 17 17:24:20 2013 +0200) 
-of Houdini, plus a mini-patch from your truly 
-(see L<https://github.com/vmg/houdini/pull/13>).
+the commit
+L<https://github.com/christianbundy/houdini/commit/1fcafc310573b0f91bd4fc77b22b95bc4e6ecbff>
+of Houdini.
 
 =head1 FUNCTIONS
 
@@ -116,6 +116,8 @@ and I<unescape_js>) and I<:all> (for... well, all of them).
 
 Houdini (natch) - L<https://github.com/vmg/houdini>
 
+The active fork currently used - L<https://github.com/christianbundy/houdini>
+
 =head1 AUTHOR
 
 Yanick Champoux <yanick@cpan.org>
